@@ -413,6 +413,7 @@ def tcn_stft(nb_freq: int, nb_classes: int, nb_hist: int = 1, nb_filters: int =
              use_skip_connections: bool = True, return_sequences: bool = True,
              dropout_rate: float = 0.00, padding: str = 'same', sample_weight_mode: str = None,
              nb_pre_conv: int = 0, pre_nb_dft: int = 64,
+             nb_lstm_units: int = 0,
              learning_rate: float = 0.0005, upsample: bool = True,
              use_separable: bool = False,
              **kwignored):
@@ -438,6 +439,7 @@ def tcn_stft(nb_freq: int, nb_classes: int, nb_hist: int = 1, nb_filters: int =
         pre_nb_dft (int, optional): Number of filters (roughly corresponding to filters) in the STFT frontend.
                                     Defaults to 64.
         learning_rate (float, optional) Defaults to 0.0005
+        nb_lstm_units (int, optional): Defaults to 0.
         upsample (bool, optional): whether or not to restore the model output to the input samplerate.
                                    Should generally be True during training and evaluation but my speed up inference.
                                    Defaults to True.
@@ -462,10 +464,16 @@ def tcn_stft(nb_freq: int, nb_classes: int, nb_hist: int = 1, nb_filters: int =
                       activation=activation, use_skip_connections=use_skip_connections, padding=padding,
                       dropout_rate=dropout_rate, return_sequences=return_sequences,
                       use_separable=use_separable)(out)
+
+    if nb_lstm_units > 0:
+        x = kl.Bidirectional(kl.LSTM(units=nb_lstm_units, return_sequences=True))(x)
+
     x = kl.Dense(nb_classes)(x)
     x = kl.Activation('softmax')(x)
+
     if nb_pre_conv > 0 and upsample:
         x = kl.UpSampling1D(size=2**nb_pre_conv)(x)
+
     output_layer = x
 
     model = keras.models.Model(input_layer, output_layer, name='TCN')
